@@ -289,6 +289,10 @@
 #define __NR_fspick		433
 #define __NR_pidfd_open		434
 #define __NR_clone3		435
+#define __NR_close_range	436
+#define __NR_openat2		437
+#define __NR_pidfd_getfd	438
+#define __NR_faccessat2		439
 
 #define SYS_io_setup 0
 #define SYS_io_destroy 1
@@ -581,3 +585,7 @@
 #define SYS_fspick		433
 #define SYS_pidfd_open		434
 #define SYS_clone3		435
+#define SYS_close_range	436
+#define SYS_openat2		437
+#define SYS_pidfd_getfd	438
+#define SYS_faccessat2		439
